@@ -101,7 +101,7 @@ class JSONStore(object):
 
         # Conditional PUT. This is useful for implementing counters, eg.
         def condition(old):
-            etag = '"%s"' % sha(dumps(old, cls=DatetimeEncoder)).hexdigest()
+            etag = '%s' % sha(dumps(old, cls=DatetimeEncoder)).hexdigest()  # no quotes to check against req.if_match
             return etag in req.if_match or (
                     req.if_unmodified_since and 
                     req.if_unmodified_since >= old['__updated__'])
