@@ -43,7 +43,7 @@ class EntryManager(object):
         if self.index not in LOCAL.conns:
             LOCAL.conns[self.index] = sqlite3.connect(self.index, 
                     detect_types=sqlite3.PARSE_DECLTYPES|sqlite3.PARSE_COLNAMES)
-        LOCAL.conns[self.index].create_function("REGEXP", 2, regexp)
+        #LOCAL.conns[self.index].create_function("REGEXP", 2, regexp)
         return LOCAL.conns[self.index]
 
     def _create_table(self):
@@ -183,8 +183,12 @@ class EntryManager(object):
                 if token not in target:
                     target[token] = {}
                 target = target[token]
+            leaf = leaf.replace('%2E', '.')
             if tokens[-1] in target:
-                target[ tokens[-1] ] = [ target[ tokens[-1] ], leaf ]
+                if isinstance(target[ tokens[-1] ], list):
+                    target[ tokens[-1] ].append(leaf)
+                else:
+                    target[ tokens[-1] ] = [ target[ tokens[-1] ], leaf ]
             else:
                 target[ tokens[-1] ] = leaf
 
